@@ -1,5 +1,5 @@
 package WWW::FetchStory::Fetcher::AO3;
-$WWW::FetchStory::Fetcher::AO3::VERSION = '0.2001';
+$WWW::FetchStory::Fetcher::AO3::VERSION = '0.2002';
 use strict;
 use warnings;
 =head1 NAME
@@ -8,7 +8,7 @@ WWW::FetchStory::Fetcher::AO3 - fetching module for WWW::FetchStory
 
 =head1 VERSION
 
-version 0.2001
+version 0.2002
 
 =head1 DESCRIPTION
 
@@ -240,12 +240,9 @@ sub parse_author {
 
     my $content = $args{content};
 
+    say STDERR "start of parse_author";
     my $author = '';
-    if ($content =~ m!<a href="/users/\w+/pseuds/\w+" class="login author">([^<]+)</a>!)
-    {
-	$author = $1;
-    }
-    elsif ($content =~ m!&lt;a href=&quot;http://archiveofourown.org/users/\w+&quot;&gt;&lt;strong&gt;([-\w\s]+)&lt;/strong&gt;&lt;/a&gt;!)
+    if ($content =~ m! href="/users/\w+/pseuds/\w+">([^<]+)</a>!)
     {
 	$author = $1;
     }
